/*
 * playbackbackend.h
 *
 *  Created on: 05.12.2010
 *      Author: darkstar
 */

#ifndef PLAYBACKBACKEND_H_
#define PLAYBACKBACKEND_H_

#include <qobject.h>
#include <qwidget.h>

#ifdef QT4
#include <QMap>
#else
#include <qdict.h>
#endif

#include "media.h"
#include "configuration.h"

class AbstractPlaybackBackend;

class PlaybackBackendConfigWidget : public QWidget
{
    Q_OBJECT
public:
    PlaybackBackendConfigWidget(QWidget *parent = 0) : QWidget(parent) {}
    virtual ~PlaybackBackendConfigWidget() {}

    virtual void setStatesByFormats(const QString& formats) {};
    virtual void formatsChanged(const QString& formats) {};
    virtual void saveStates() {};
};

class AbstractPlaybackBackendFactory
{
public:
    virtual ~AbstractPlaybackBackendFactory() {}

    virtual QString internalClassName() const = 0;
    virtual QString friendlyDisplayName() const = 0;

    virtual AbstractPlaybackBackend *createInstance() = 0;

    virtual bool supportsFormatSpecificConfigs() { return false; }
    virtual void setFormatSpecificConfigDefaults(Configuration &config) {}
    virtual PlaybackBackendConfigWidget *createConfigWidget(QWidget *parent) { return NULL; }
};

class AbstractPlaybackBackend: public QObject
{
    Q_OBJECT
public:
    AbstractPlaybackBackend(QObject *parent = 0) : QObject(parent) {}
    virtual ~AbstractPlaybackBackend() {}

    enum PlayResult {
        PlaybackInitiated,
        MediaNotFound,
        MediaNotSupported,
        InitializationFailed
    };

    virtual PlayResult play(Media *) = 0;

    virtual bool isRunning() const = 0;
    virtual bool isPlaying() const = 0;
    virtual bool isPaused() const = 0;

public slots:
    virtual void pause() = 0;
    virtual void stop() = 0;
    virtual void seekRelativeSeconds(int) = 0;
    virtual void seekAbsolutePercentage(int) = 0;
    virtual void seekAbsoluteSeconds(int) = 0;

signals:
    void started();
    void paused();
    void resumed();
    void shutdown();
    void eof();

    void errorMessage(QString);
    void output(const QString&);
    void currentPlayTime(int);
};

#ifdef QT4
typedef QList<AbstractPlaybackBackendFactory *> AbstractPlaybackBackendList;
#else
typedef QList<AbstractPlaybackBackendFactory> AbstractPlaybackBackendList;
#endif

class PlaybackBackendRegistry
{
public:
    virtual ~PlaybackBackendRegistry() {}

    static PlaybackBackendRegistry& singleton();
#	define globalPlaybackBackendRegistry PlaybackBackendRegistry::singleton()

    AbstractPlaybackBackend *createInstanceOfDefaultBackend();
    AbstractPlaybackBackend *createNewInstance(const QString &className);

    void registerFactory(AbstractPlaybackBackendFactory *factory);
    AbstractPlaybackBackendFactory *findFactory(const QString &className);
    AbstractPlaybackBackendFactory *defaultFactory();

    AbstractPlaybackBackendList &factories() { return factories_; }

private:
    AbstractPlaybackBackendList factories_;
#ifdef QT4
    QHash<QString, AbstractPlaybackBackendFactory *> factoriesMap_;
#else
    QDict<AbstractPlaybackBackendFactory> factoriesMap_;
#endif
};

#endif /* PLAYBACKBACKEND_H_ */
