/* -*- mode: c++; tab-width: 4; c-basic-offset: 4 -*- */
/*
 * Copyright (C) 2005 Atmark <atmarkat _AT_ msn _DOT_ com>
 *                    AGAWA Koji <i _AT_ atty _DOT_ jp>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <qapplication.h>
#include <qlayout.h>
#include <qlabel.h>

#ifdef QT4
#include <QDesktopWidget>
#include <QScrollArea>
#include <QGroupBox>
#include <QTextEdit>
#else
#include <qtextview.h>
#include <qvgroupbox.h>
#include <qscrollview.h>
#include <qvbox.h>
#endif

#include "aboutdialog.h"
#include "configuration.h"
#include "compathack.h"

AboutDialog::AboutDialog(QWidget *parent)
    : QWidget(parent)
{
    setWindowTitle(tr("About Quasar Media Player"));

#ifdef MAEMO
    setAttribute(Qt::WA_Maemo5StackedWindow);
#endif

#ifndef QT4
    setWFlags(getWFlags() | Qt::WDestructiveClose);
    QScrollView *scrollView = new QScrollView(this);
    scrollView->setFrameStyle(QScrollView::NoFrame);
    scrollView->setMargin(4);
    scrollView->setResizePolicy(QScrollView::AutoOneFit);

    QWidget *bigbox = new QWidget(scrollView->viewport());
    scrollView->addChild(bigbox);
#else
    QScrollArea *scrollView = new QScrollArea(this);
    scrollView->setWidgetResizable(true);
    scrollView->setFrameStyle(QScrollArea::NoFrame);

    setWindowFlags(windowFlags() | Qt::Window);
    setAttribute(Qt::WA_DeleteOnClose);

    QWidget *bigbox = new QWidget(this);
    scrollView->setWidget(bigbox);
    bigbox->show();
#endif

    QVBoxLayout *bigboxlayout = new QVBoxLayout(bigbox);
    bigboxlayout->setMargin(0);
    bigboxlayout->setSpacing(4);

#ifdef QT4
    QGroupBox *copyrightBox = new QGroupBox(tr("Copyright information"), bigbox);
    QVBoxLayout *copyrightBoxLayout = new QVBoxLayout(copyrightBox);
    bigboxlayout->addWidget(copyrightBox);

    QTextEdit *about = new QTextEdit(copyrightBox);
    about->setReadOnly(true);

    copyrightBoxLayout->addWidget(about);
#else
    QVGroupBox *copyrightBox = new QVGroupBox(tr("Copyright information"), bigbox);
    bigboxlayout->addWidget(copyrightBox);

    QTextView *about = new QTextView(copyrightBox);
    about->setTextFormat(Qt::RichText);
#endif

    QString revision = "";
    if (QString(APPREVISION) != "#Revision#")
        revision = " (" + QString(APPREVISION) + ")";

    about->setText(
#ifdef QT4
            "<html><head/><body>"
#endif
            "<bold>Quasar Media Player " + QString("%1.%2").arg(APPVERSION_MAJOR).arg(APPVERSION_MINOR) + revision + "</bold><br/>"
            "Copyright (C) 2006-2008 by Andre Beckedorf <a href=\"mailto:evilJazz@katastrophos.net\">(evilJazz@katastrophos.net)</a><br/>"
            "<br/>"
            "This software is licensed under the terms of the GNU General Public License version 2.<br/>"
            "<br/>"
            "For more information please visit:<br/>"
            "<a href=\"http://katastrophos.net/quasar\">http://katastrophos.net/quasar</a><br/>"
            "<br/>"
            "Based on ZPlayer by Atmark and AGAWA Koji<br/>"
            "MPlayer for Zaurus by AGAWA Koji<br/>"
            "TagLib by Scott Wheeler et al.<br/>"
            "TK File Dialog (C) by TKmix, modified by AGAWA Koji and Andre Beckedorf<br/>"
            "TKvol (C) TKmix<br/>"
            "KeyHelperConf (C) yakty"
#ifdef QT4
            "</body></html>"
#endif
    );

    QHBoxLayout *layout = new QHBoxLayout(this);
    layout->addWidget(scrollView);

#ifdef QTOPIA
    showMaximized();
#else
    if (qApp->desktop()->width() < 800 || qApp->desktop()->height() < 600)
        showMaximized();
    else
    {
        resize(640, 480);
        show();
    }
#endif
}
